"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GraphQLDate = void 0;
const assertErr = require("assert-err");
const graphql_1 = require("graphql");
exports.GraphQLDate = new graphql_1.GraphQLScalarType({
    name: 'Date',
    serialize: function (value) {
        assertErr(value instanceof Date, TypeError, 'Field error: value is not an instance of Date');
        assertErr(!isNaN(value.getTime()), TypeError, 'Field error: value is an invalid Date');
        return value.toJSON();
    },
    parseValue: function (value) {
        var date = new Date(value);
        assertErr(!isNaN(date.getTime()), TypeError, 'Field error: value is an invalid Date');
        return date;
    },
    parseLiteral: function (ast) {
        assertErr(ast.kind === graphql_1.Kind.STRING, graphql_1.GraphQLError, 'Query error: Can only parse strings to dates but got a: ' + ast.kind, [ast]);
        var result = new Date(ast.value);
        assertErr(!isNaN(result.getTime()), graphql_1.GraphQLError, 'Query error: Invalid date', [ast]);
        assertErr(ast.value === result.toJSON(), graphql_1.GraphQLError, 'Query error: Invalid date format, only accepts: YYYY-MM-DDTHH:MM:SS.SSSZ', [ast]);
        return result;
    }
});
